# PyChoreographer

A customizable Python library for automating file operations, system monitoring, and routine tasks

## Installation

```bash
$ pip install pychoreographer
```
## Features

<!-- features-begin -->

* **Environment Checker**
    * Script to validate if a project's required dependencies are installed within the current virtual environment.

<!-- features-end -->

## Usage

`pychoreographer -help` can be used to get current features
as follows:

```bash
pychoreographer -help
```

## Contributing

Interested in contributing? Check out the contributing guidelines. 
Please note that this project is released with a Code of Conduct. 
By contributing to this project, you agree to abide by its terms.

## License

`pychoreographer` was created by Rajaa Lebchiri. It is licensed under the terms
of the MIT license.

